@@ -1,8 +1,8 @@
 from django.db import models
 from django.contrib.postgres.fields import ArrayField
 
-from ..common import JURISDICTION_CLASSIFICATION_CHOICES
-from .base import OCDBase, OCDIDField
+from ..common import JURISDICTION_CLASSIFICATION_CHOICES, SESSION_CLASSIFICATION_CHOICES
+from .base import OCDBase, OCDIDField, RelatedBase
 from .division import Division
 
 
@@ -40,6 +40,7 @@ class Jurisdiction(OCDBase):
         Division,
         related_name="jurisdictions",
         db_index=True,
+        null=True,
         help_text="A link to a Division related to this Jurisdiction.",
         # don't allow deletion of a division that a Jurisdiction depends upon
         on_delete=models.PROTECT,
@@ -50,3 +51,25 @@ class Jurisdiction(OCDBase):
 
     def __str__(self):
         return self.name
+
+
+class LegislativeSession(RelatedBase):
+    jurisdiction = models.ForeignKey(
+        Jurisdiction,
+        related_name="legislative_sessions",
+        # should be hard to delete Jurisdiction
+        on_delete=models.PROTECT,
+    )
+    identifier = models.CharField(max_length=100)
+    name = models.CharField(max_length=300)
+    classification = models.CharField(
+        max_length=100, choices=SESSION_CLASSIFICATION_CHOICES, blank=True
+    )
+    start_date = models.CharField(max_length=10)  # YYYY[-MM[-DD]]
+    end_date = models.CharField(max_length=10)  # YYYY[-MM[-DD]]
+
+    def __str__(self):
+        return "{} {}".format(self.jurisdiction, self.name)
+
+    class Meta:
+        db_table = "opencivicdata_legislativesession"
