@@ -91,6 +91,7 @@ class BaseImporter(object):
         limit_spec(spec)                [optional, required if pseudo_ids are used]
         prepare_for_db(data)            [optional]
         postimport()                    [optional]
+        update_computed_fields(obj)     [optional]
     """
 
     _type = None
@@ -131,6 +132,9 @@ class BaseImporter(object):
     def postimport(self):
         pass
 
+    def update_computed_fields(self, obj):
+        pass
+
     def resolve_json_id(self, json_id, allow_no_match=False):
         """
             Given an id found in scraped JSON, return a DB id for the object.
@@ -213,6 +217,8 @@ class BaseImporter(object):
 
         for data in dicts:
             json_id = data.pop("_id")
+            if self._type == "vote_event":
+                data.pop("bill_identifier", None)
 
             # map duplicates (using omnihash to tell if json dicts are identical-ish)
             objhash = omnihash(data)
@@ -252,6 +258,8 @@ class BaseImporter(object):
 
         # remove the JSON _id (may still be there if called directly)
         data.pop("_id", None)
+        if self._type == "vote_event":
+            data.pop("bill_identifier", None)
 
         # add fields/etc.
         data = self.apply_transformers(data)
@@ -285,19 +293,25 @@ class BaseImporter(object):
                 what = "update"
 
             if what == "update":
+                # make sure to do this after create related
+                self.update_computed_fields(obj)
                 obj.save()
 
         # need to create the data
         else:
             what = "insert"
             try:
-                obj = self.model_class.objects.create(**data)
+                obj = self.model_class(**data)
+                obj.save()
             except Exception as e:
                 raise DataImportError(
                     "{} while importing {} as {}".format(e, data, self.model_class)
                 )
             self._create_related(obj, related, self.related_models)
 
+            # make sure to do this after create related
+            self.update_computed_fields(obj)
+
             # Fire post-save signal after related objects are created to allow
             # for handlers make use of related objects
             post_save.send(sender=self.model_class, instance=obj, created=True)
