@@ -13,7 +13,6 @@ schema = {
         "name": {"type": "string", "minLength": 1},
         "other_names": other_names,
         "identifiers": identifiers,
-        "sort_name": {"type": "string"},
         "family_name": {"type": "string"},
         "given_name": {"type": "string"},
         "gender": {"type": "string"},
@@ -22,7 +21,6 @@ schema = {
         "image": {"format": "uri-blank", "type": "string"},
         "summary": {"type": "string"},
         "biography": {"type": "string"},
-        "national_identity": {"type": "string"},
         "contact_details": contact_details,
         "links": links,
         "sources": sources,
