@@ -1,3 +1,6 @@
+import os
+import dj_database_url
+
 # django settings for tests
 SECRET_KEY = "test"
 INSTALLED_APPS = (
@@ -5,13 +8,16 @@ INSTALLED_APPS = (
     "openstates.data",
     "openstates.reports",
 )
+MIDDLEWARE_CLASSES = ()
 DATABASES = {
     "default": {
-        "ENGINE": "django.contrib.gis.db.backends.postgis",
+        "ENGINE": "django.db.backends.postgresql",
         "NAME": "test",
         "USER": "test",
         "PASSWORD": "test",
-        "HOST": "localhost",
+        "HOST": os.environ.get("POSTGRES_HOST", "localhost"),
     }
 }
-MIDDLEWARE_CLASSES = ()
+DATABASE_URL = os.environ.get("OVERRIDE_DATABASE_URL")
+if DATABASE_URL:
+    DATABASES = {"default": dj_database_url.parse(DATABASE_URL)}
